@@ -1,3 +1,4 @@
+from functools import partial
 from typing import Type
 
 from django.conf import settings
@@ -5,36 +6,21 @@ from django.contrib.auth import get_user_model
 from django.core.checks import register
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import Model
-from rest_framework.authentication import TokenAuthentication
 from rest_framework.settings import api_settings
 
+from rest_registration.auth_token_managers import AbstractAuthTokenManager
 from rest_registration.decorators import simple_check
+from rest_registration.enums import ErrorCode, WarningCode
 from rest_registration.notifications.email import parse_template_config
 from rest_registration.settings import registration_settings
 from rest_registration.utils.common import implies
 from rest_registration.utils.users import (
+    get_user_email_field_name,
     get_user_login_field_names,
     is_model_field_unique
 )
 
 
-class ErrorCode:  # pylint: disable=too-few-public-methods
-    NO_RESET_PASSWORD_VER_URL = 'E001'
-    NO_REGISTER_VER_URL = 'E002'
-    NO_REGISTER_EMAIL_VER_URL = 'E003'
-    NO_VER_FROM_EMAIL = 'E004'
-    NO_TOKEN_AUTH_CONFIG = 'E005'
-    NO_TOKEN_AUTH_INSTALLED = 'E006'
-    INVALID_EMAIL_TEMPLATE_CONFIG = 'E007'
-    NO_AUTH_INSTALLED = 'E008'
-    DRF_INCOMPATIBLE_DJANGO_AUTH_BACKEND = 'E009'
-    LOGIN_FIELDS_NOT_UNIQUE = 'E010'
-
-
-class WarningCode:  # pylint: disable=too-few-public-methods
-    REGISTER_VERIFICATION_MULTIPLE_AUTO_LOGIN = 'W001'
-
-
 @register()
 @simple_check(
     'django.contrib.auth is not in INSTALLED_APPS',
@@ -101,32 +87,51 @@ def verification_from_check() -> bool:
 @register()
 @simple_check(
     'LOGIN_RETRIEVE_TOKEN is set but'
-    ' TokenAuthentication is not in DEFAULT_AUTHENTICATION_CLASSES',
+    ' the matching token authentication class is not'
+    ' in DEFAULT_AUTHENTICATION_CLASSES',
     ErrorCode.NO_TOKEN_AUTH_CONFIG,
 )
 def token_auth_config_check() -> bool:
     return implies(
-        registration_settings.LOGIN_RETRIEVE_TOKEN,
-        any(
-            issubclass(cls, TokenAuthentication)
-            for cls in api_settings.DEFAULT_AUTHENTICATION_CLASSES
-        )
+        _is_auth_installed() and registration_settings.LOGIN_RETRIEVE_TOKEN,
+        _is_auth_token_manager_auth_class_enabled
     )
 
 
 @register()
 @simple_check(
     'LOGIN_RETRIEVE_TOKEN is set but'
-    ' rest_framework.authtoken is not in INSTALLED_APPS',
+    ' the required Django apps are not in INSTALLED_APPS',
     ErrorCode.NO_TOKEN_AUTH_INSTALLED,
 )
 def token_auth_installed_check() -> bool:
     return implies(
-        registration_settings.LOGIN_RETRIEVE_TOKEN,
-        'rest_framework.authtoken' in settings.INSTALLED_APPS,
+        _is_auth_installed() and registration_settings.LOGIN_RETRIEVE_TOKEN,
+        _is_auth_token_manager_app_name_installed,
     )
 
 
+def _is_auth_token_manager_auth_class_enabled() -> bool:
+    auth_token_manager = _get_auth_token_manager()
+    auth_cls = auth_token_manager.get_authentication_class()
+    return any(
+        issubclass(cls, auth_cls)
+        for cls in api_settings.DEFAULT_AUTHENTICATION_CLASSES
+    )
+
+
+def _is_auth_token_manager_app_name_installed() -> bool:
+    auth_token_manager = _get_auth_token_manager()
+    app_names = auth_token_manager.get_app_names()
+    return all(app_name in settings.INSTALLED_APPS for app_name in app_names)
+
+
+def _get_auth_token_manager() -> AbstractAuthTokenManager:
+    auth_token_manager_cls = registration_settings.AUTH_TOKEN_MANAGER_CLASS
+    auth_token_manager = auth_token_manager_cls()
+    return auth_token_manager
+
+
 @register()
 @simple_check(
     'REGISTER_VERIFICATION_AUTO_LOGIN is enabled,'
@@ -235,5 +240,140 @@ def _are_login_fields_unique() -> bool:
         for field_name in get_user_login_field_names())
 
 
+@register()
+@simple_check(
+    'AUTH_TOKEN_MANAGER_CLASS is not proper subclass'
+    ' of AbstractAuthTokenManager',
+    ErrorCode.INVALID_AUTH_TOKEN_MANAGER_CLASS,
+)
+def valid_auth_token_manager_class_proper_subclass_check() -> bool:
+    return implies(
+        _is_auth_installed(),
+        _is_auth_token_manager_proper_subclass,
+    )
+
+
+@register()
+@simple_check(
+    'AUTH_TOKEN_MANAGER_CLASS is not implementing'
+    ' method get_authentication_class',
+    ErrorCode.INVALID_AUTH_TOKEN_MANAGER_CLASS,
+)
+def valid_auth_token_manager_class_get_authentication_class_check() -> bool:
+    return implies(
+        _is_auth_installed(),
+        partial(
+            _is_auth_token_manager_class_implementing_method,
+            'get_authentication_class'),
+    )
+
+
+@register()
+@simple_check(
+    'AUTH_TOKEN_MANAGER_CLASS is not implementing method provide_token',
+    ErrorCode.INVALID_AUTH_TOKEN_MANAGER_CLASS,
+)
+def valid_auth_token_manager_class_provide_token_check() -> bool:
+    return implies(
+        _is_auth_installed(),
+        partial(
+            _is_auth_token_manager_class_implementing_method,
+            'provide_token'),
+    )
+
+
+# TODO: Issue #114 - remove deprecation check
+@register()
+@simple_check(
+    'LOGIN_SERIALIZER_CLASS contains deprecated get_authenticated_user method,'
+    ' which will be removed in version 0.7.0',
+    WarningCode.DEPRECATION
+)
+def deprecated_login_serializer_check() -> bool:
+    serializer_class = registration_settings.LOGIN_SERIALIZER_CLASS
+    deprecated = (
+        hasattr(serializer_class, 'get_authenticated_user')
+        and callable(serializer_class.get_authenticated_user))
+    return not deprecated
+
+
+# TODO: Issue #114 - remove deprecation check
+@register()
+@simple_check(
+    'SEND_RESET_PASSWORD_LINK_SERIALIZER_CLASS contains deprecated'
+    ' get_user_or_none method, which will be removed in version 0.7.0',
+    WarningCode.DEPRECATION
+)
+def deprecated_send_reset_password_link_serializer_check() -> bool:
+    serializer_class = registration_settings.SEND_RESET_PASSWORD_LINK_SERIALIZER_CLASS
+    deprecated = (
+        hasattr(serializer_class, 'get_user_or_none')
+        and callable(serializer_class.get_user_or_none))
+    return not deprecated
+
+
+# TODO: Issue #114 - remove deprecation check
+@register()
+@simple_check(
+    'REGISTER_EMAIL_SERIALIZER_CLASS contains deprecated get_email method,'
+    ' which will be removed in version 0.7.0',
+    WarningCode.DEPRECATION
+)
+def deprecated_register_email_serializer_check() -> bool:
+    serializer_class = registration_settings.REGISTER_EMAIL_SERIALIZER_CLASS
+    deprecated = (
+        hasattr(serializer_class, 'get_email')
+        and callable(serializer_class.get_email))
+    return not deprecated
+
+
+@register()
+@simple_check(
+    'REGISTER_EMAIL_SERIALIZER_CLASS does not contain email field',
+    ErrorCode.INVALID_REGISTER_EMAIL_SERIALIZER_CLASS
+)
+def valid_register_email_serializer_check() -> bool:
+    serializer_class = registration_settings.REGISTER_EMAIL_SERIALIZER_CLASS
+    serializer = serializer_class()
+    try:
+        return bool(serializer.fields['email'])
+    except KeyError:
+        return False
+
+
+@register()
+@simple_check(
+    'SEND_RESET_PASSWORD_LINK_SERIALIZER_USE_EMAIL is set'
+    ' but email field is not unique',
+    ErrorCode.NON_UNIQUE_FIELD_USED_AS_UNIQUE
+)
+def send_reset_password_link_serializer_email_unique_check() -> bool:
+    return implies(
+        registration_settings.SEND_RESET_PASSWORD_LINK_SERIALIZER_USE_EMAIL,
+        _is_email_field_unique,
+    )
+
+
+def _is_email_field_unique() -> bool:
+    user_cls = get_user_model()  # type: Type[Model]
+    user_meta = user_cls._meta  # pylint: disable=protected-access
+    email_field_name = get_user_email_field_name()
+    return is_model_field_unique(user_meta.get_field(email_field_name))
+
+
+def _is_auth_token_manager_proper_subclass() -> bool:
+    cls = registration_settings.AUTH_TOKEN_MANAGER_CLASS
+    return (
+        issubclass(cls, AbstractAuthTokenManager)
+        and cls != AbstractAuthTokenManager)
+
+
+def _is_auth_token_manager_class_implementing_method(method_name: str) -> bool:
+    cls = registration_settings.AUTH_TOKEN_MANAGER_CLASS
+    cls_method = getattr(cls, method_name, None)
+    abstract_method = getattr(AbstractAuthTokenManager, method_name)
+    return cls_method is not abstract_method
+
+
 def _is_auth_installed() -> bool:
     return 'django.contrib.auth' in settings.INSTALLED_APPS
