@@ -5,6 +5,10 @@ from typing import Callable, List, Union
 from django.core import checks
 
 from rest_registration.enums import ErrorCode, WarningCode
+from rest_registration.utils.functools import update_wrapper
+
+WRAPPER_ASSIGNMENTS_WITHOUT_ANNOTATIONS = tuple(
+    a for a in functools.WRAPPER_ASSIGNMENTS if a != '__annotations__')
 
 
 def api_view_serializer_class_getter(serializer_class_getter):
@@ -46,7 +50,6 @@ def simple_check(
 
     def decorator(predicate: Callable[[], bool]):
 
-        @functools.wraps(predicate)
         def check_fun(
                 app_configs, **kwargs) -> List[checks.CheckMessage]:
             from rest_registration.apps import RestRegistrationConfig  # noqa: E501 pylint: disable=import-outside-toplevel, cyclic-import
@@ -67,6 +70,11 @@ def simple_check(
                 )
             return messages
 
+        update_wrapper(
+            check_fun, predicate,
+            assigned=WRAPPER_ASSIGNMENTS_WITHOUT_ANNOTATIONS,
+            set_wrapped=False)
+
         return check_fun
 
     return decorator
