@@ -1,11 +1,17 @@
+from typing import TYPE_CHECKING, Any, Dict, Optional
 from urllib.parse import urlencode
 
 from django.core import signing
 
 from rest_registration.exceptions import SignatureExpired, SignatureInvalid
+from rest_registration.notifications.enums import NotificationMethod, NotificationType
+from rest_registration.verification import URLParamsSigner
+
+if TYPE_CHECKING:
+    from django.contrib.auth.base_user import AbstractBaseUser
 
 
-def verify_signer_or_bad_request(signer):
+def verify_signer_or_bad_request(signer: URLParamsSigner) -> None:
     try:
         signer.verify()
     except signing.SignatureExpired:
@@ -14,7 +20,7 @@ def verify_signer_or_bad_request(signer):
         raise SignatureInvalid() from None
 
 
-def build_default_verification_url(signer):
+def build_default_verification_url(signer: URLParamsSigner) -> str:
     base_url = signer.get_base_url()
     params = urlencode(signer.get_signed_data())
     url = '{base_url}?{params}'.format(base_url=base_url, params=params)
@@ -24,8 +30,11 @@ def build_default_verification_url(signer):
 
 
 def build_default_template_context(
-        user, user_address, data,
-        notification_type=None, notification_method=None):
+        user: 'AbstractBaseUser',
+        user_address: Any,
+        data: Dict[str, Any],
+        notification_type: Optional[NotificationType] = None,
+        notification_method: Optional[NotificationMethod] = None) -> Dict[str, Any]:
     context = {
         'user': user,
         'email': user_address,
